@@ -11,6 +11,8 @@ class Literals(ValueDictsBase):
 
     _info = {
         "dotnet_build_before": "Launching dotnet build inside {path}. Please wait..",
+        "dotnet_ef_database_drop": "Dropping the database...",
+        "dotnet_ef_database_reset": "Reverting all migrations...",
         "dotnet_ef_migrations_list": "Listing migrations (will take a while)...",
         "dotnet_ef_migrations_script": "Generating SQL script (will take a while)...",
         "dotnet_project_version": "The project version is {version}",
@@ -20,4 +22,3 @@ class Literals(ValueDictsBase):
         "dotnet_restore_err": "Something went wrong while restoring {path}. Please check the logs and try again.",
         "dotnet_build_err": "Something went wrong while building {path}. Please check the logs and try again.",
     }
-
